@@ -1,4 +1,4 @@
-from typing import Dict, Optional, List
+from typing import Any, Dict, Optional, List
 from pydantic.main import BaseModel
 
 class Manifest(BaseModel):
@@ -10,4 +10,6 @@ class Manifest(BaseModel):
     image: Optional[str]
     languages: Optional[List[str]]
     auto_train: bool = True
-    topic_access: Optional[Dict[str, int]]
\ No newline at end of file
+    topic_access: Optional[Dict[str, int]]
+    default_config: Optional[Dict[str, Any]]
+    schema_config: Optional[Dict[str, Any]]
\ No newline at end of file
